@@ -1,4 +1,4 @@
 from .inputs import Inputs  # expose for easy import
 from .outputs import Outputs
-from .base import DAG
+from .base import DAG, GroupedDAG
 from .task import task
